==> rxode2_3.0.2.tar.gz: rxode2/inst/include/rxode2parse_control.h <==
#pragma once
#ifndef __rxode2parse_control_H__
#define __rxode2parse_control_H__
#define Rxc_scale 0
#define Rxc_method 1
#define Rxc_atol 2
#define Rxc_rtol 3
#define Rxc_maxsteps 4
#define Rxc_hmin 5
#define Rxc_hmax 6
#define Rxc_hini 7
#define Rxc_maxordn 8
#define Rxc_maxords 9
#define Rxc_covsInterpolation 10
#define Rxc_addCov 11
#define Rxc_returnType 12
#define Rxc_sigma 13
#define Rxc_sigmaDf 14
#define Rxc_nCoresRV 15
#define Rxc_sigmaIsChol 16
#define Rxc_sigmaSeparation 17
#define Rxc_sigmaXform 18
#define Rxc_nDisplayProgress 19
#define Rxc_amountUnits 20
#define Rxc_timeUnits 21
#define Rxc_addDosing 22
#define Rxc_stateTrim 23
#define Rxc_updateObject 24
#define Rxc_omega 25
#define Rxc_omegaDf 26
#define Rxc_omegaIsChol 27
#define Rxc_omegaSeparation 28
#define Rxc_omegaXform 29
#define Rxc_nSub 30
#define Rxc_thetaMat 31
#define Rxc_thetaDf 32
#define Rxc_thetaIsChol 33
#define Rxc_nStud 34
#define Rxc_dfSub 35
#define Rxc_dfObs 36
#define Rxc_seed 37
#define Rxc_nsim 38
#define Rxc_minSS 39
#define Rxc_maxSS 40
#define Rxc_strictSS 41
#define Rxc_infSSstep 42
#define Rxc_istateReset 43
#define Rxc_subsetNonmem 44
#define Rxc_hmaxSd 45
#define Rxc_maxAtolRtolFactor 46
#define Rxc_from 47
#define Rxc_to 48
#define Rxc_by 49
#define Rxc_length_out 50
#define Rxc_iCov 51
#define Rxc_keep 52
#define Rxc_keepF 53
#define Rxc_drop 54
#define Rxc_warnDrop 55
#define Rxc_omegaLower 56
#define Rxc_omegaUpper 57
#define Rxc_sigmaLower 58
#define Rxc_sigmaUpper 59
#define Rxc_thetaLower 60
#define Rxc_thetaUpper 61
#define Rxc_indLinPhiM 62
#define Rxc_indLinPhiTol 63
#define Rxc_indLinMatExpType 64
#define Rxc_indLinMatExpOrder 65
#define Rxc_idFactor 66
#define Rxc_mxhnil 67
#define Rxc_hmxi 68
#define Rxc_warnIdSort 69
#define Rxc_ssAtol 70
#define Rxc_ssRtol 71
#define Rxc_safeZero 72
#define Rxc_sumType 73
#define Rxc_prodType 74
#define Rxc_sensType 75
#define Rxc_linDiff 76
#define Rxc_linDiffCentral 77
#define Rxc_resample 78
#define Rxc_resampleID 79
#define Rxc_maxwhile 80
#define Rxc_cores 81
#define Rxc_atolSens 82
#define Rxc_rtolSens 83
#define Rxc_ssAtolSens 84
#define Rxc_ssRtolSens 85
#define Rxc_simVariability 86
#define Rxc_nLlikAlloc 87
#define Rxc_useStdPow 88
#define Rxc_naTimeHandle 89
#define Rxc_addlKeepsCov 90
#define Rxc_addlDropSs 91
#define Rxc_ssAtDoseTime 92
#define Rxc_ss2cancelAllPending 93
#define Rxc_naInterpolation 94
#define Rxc_keepInterpolation 95
#define Rxc_safeLog 96
#define Rxc_safePow 97
#define Rxc__zeros 98
#define RxMv_params 0
#define RxMv_lhs 1
#define RxMv_state 2
#define RxMv_trans 3
#define RxMv_model 4
#define RxMv_ini 5
#define RxMv_dfdy 6
#define RxMv_sens 7
#define RxMv_state_ignore 8
#define RxMv_version 9
#define RxMv_normal_state 10
#define RxMv_needSort 11
#define RxMv_nMtime 12
#define RxMv_extraCmt 13
#define RxMv_stateExtra 14
#define RxMv_dvid 15
#define RxMv_indLin 16
#define RxMv_flags 17
#define RxMv_slhs 18
#define RxMv_alag 19
#define RxMv_udf 20
#define RxMv_interp 21
#define RxMv_strAssign 22
#define RxMv_lhsStr 23
#define RxMv_stateProp 24
#define RxMv_sensProp 25
#define RxMv_normProp 26
#define RxMv_stateOrd 27
#define RxMv_timeId 28
#define RxMv_md5 29
#define RxMvFlag_ncmt 0
#define RxMvFlag_ka 1
#define RxMvFlag_linB 2
#define RxMvFlag_maxeta 3
#define RxMvFlag_maxtheta 4
#define RxMvFlag_hasCmt 5
#define RxMvFlag_linCmt 6
#define RxMvFlag_linCmtFlg 7
#define RxMvFlag_nIndSim 8
#define RxMvFlag_simflg 9
#define RxMvFlag_thread 10
#define RxMvFlag_nLlik 11

#define RxMvTrans_lib_name 0
#define RxMvTrans_jac 1
#define RxMvTrans_prefix 2
#define RxMvTrans_dydt 3
#define RxMvTrans_calc_jac 4
#define RxMvTrans_calc_lhs 5
#define RxMvTrans_model_vars 6
#define RxMvTrans_theta 7
#define RxMvTrans_inis 8
#define RxMvTrans_dydt_lsoda 9
#define RxMvTrans_calc_jac_lsoda 10
#define RxMvTrans_ode_solver_solvedata 11
#define RxMvTrans_ode_solver_get_solvedata 12
#define RxMvTrans_dydt_liblsoda 13
#define RxMvTrans_F 14
#define RxMvTrans_Lag 15
#define RxMvTrans_Rate 16
#define RxMvTrans_Dur 17
#define RxMvTrans_mtime 18
#define RxMvTrans_assignFuns 19
#define RxMvTrans_ME 20
#define RxMvTrans_IndF 21
#define RxTrans_ndose 0
#define RxTrans_nobs 1
#define RxTrans_nid 2
#define RxTrans_cov1 3
#define RxTrans_covParPos 4
#define RxTrans_covParPosTV 5
#define RxTrans_sub0 6
#define RxTrans_baseSize 7
#define RxTrans_nTv 8
#define RxTrans_lst 9
#define RxTrans_nme 10
#define RxTrans_covParPos0 11
#define RxTrans_covUnits 12
#define RxTrans_pars 13
#define RxTrans_allBolus 14
#define RxTrans_allInf 15
#define RxTrans_mxCmt 16
#define RxTrans_lib_name 17
#define RxTrans_addCmt 18
#define RxTrans_cmtInfo 19
#define RxTrans_idLvl 20
#define RxTrans_allTimeVar 21
#define RxTrans_keepDosingOnly 22
#define RxTrans_censAdd 23
#define RxTrans_limitAdd 24
#define RxTrans_levelInfo 25
#define RxTrans_idInfo 26
#define RxTrans_maxShift 27
#define RxTrans_keepL 28
#define RxTrans_maxItemsPerId 29
#define RxTransNames CharacterVector _en(30);_en[0]="ndose";_en[1]="nobs";_en[2]="nid";_en[3]="cov1";_en[4]="covParPos";_en[5]="covParPosTV";_en[6]="sub0";_en[7]="baseSize";_en[8]="nTv";_en[9]="lst";_en[10]="nme";_en[11]="covParPos0";_en[12]="covUnits";_en[13]="pars";_en[14]="allBolus";_en[15]="allInf";_en[16]="mxCmt";_en[17]="lib_name";_en[18]="addCmt";_en[19]="cmtInfo";_en[20]="idLvl";_en[21]="allTimeVar";_en[22]="keepDosingOnly";_en[23]="censAdd";_en[24]="limitAdd";_en[25]="levelInfo";_en[26]="idInfo";_en[27]="maxShift";_en[28]="keepL";_en[29]="maxItemsPerId";e.names() = _en;

#endif // __rxode2parse_control_H__

==> rxode2_4.0.3.tar.gz: rxode2/inst/include/rxode2parse_control.h <==
#pragma once
#ifndef __rxode2parse_control_H__
#define __rxode2parse_control_H__
#define Rxc_scale 0
#define Rxc_method 1
#define Rxc_atol 2
#define Rxc_rtol 3
#define Rxc_maxsteps 4
#define Rxc_hmin 5
#define Rxc_hmax 6
#define Rxc_hini 7
#define Rxc_maxordn 8
#define Rxc_maxords 9
#define Rxc_covsInterpolation 10
#define Rxc_addCov 11
#define Rxc_returnType 12
#define Rxc_sigma 13
#define Rxc_sigmaDf 14
#define Rxc_nCoresRV 15
#define Rxc_sigmaIsChol 16
#define Rxc_sigmaSeparation 17
#define Rxc_sigmaXform 18
#define Rxc_nDisplayProgress 19
#define Rxc_amountUnits 20
#define Rxc_timeUnits 21
#define Rxc_addDosing 22
#define Rxc_stateTrim 23
#define Rxc_updateObject 24
#define Rxc_omega 25
#define Rxc_omegaDf 26
#define Rxc_omegaIsChol 27
#define Rxc_omegaSeparation 28
#define Rxc_omegaXform 29
#define Rxc_nSub 30
#define Rxc_thetaMat 31
#define Rxc_thetaDf 32
#define Rxc_thetaIsChol 33
#define Rxc_nStud 34
#define Rxc_dfSub 35
#define Rxc_dfObs 36
#define Rxc_seed 37
#define Rxc_nsim 38
#define Rxc_minSS 39
#define Rxc_maxSS 40
#define Rxc_strictSS 41
#define Rxc_infSSstep 42
#define Rxc_istateReset 43
#define Rxc_subsetNonmem 44
#define Rxc_hmaxSd 45
#define Rxc_maxAtolRtolFactor 46
#define Rxc_from 47
#define Rxc_to 48
#define Rxc_by 49
#define Rxc_length_out 50
#define Rxc_iCov 51
#define Rxc_keep 52
#define Rxc_keepF 53
#define Rxc_drop 54
#define Rxc_warnDrop 55
#define Rxc_omegaLower 56
#define Rxc_omegaUpper 57
#define Rxc_sigmaLower 58
#define Rxc_sigmaUpper 59
#define Rxc_thetaLower 60
#define Rxc_thetaUpper 61
#define Rxc_indLinPhiM 62
#define Rxc_indLinPhiTol 63
#define Rxc_indLinMatExpType 64
#define Rxc_indLinMatExpOrder 65
#define Rxc_idFactor 66
#define Rxc_mxhnil 67
#define Rxc_hmxi 68
#define Rxc_warnIdSort 69
#define Rxc_ssAtol 70
#define Rxc_ssRtol 71
#define Rxc_safeZero 72
#define Rxc_sumType 73
#define Rxc_prodType 74
#define Rxc_resample 75
#define Rxc_resampleID 76
#define Rxc_maxwhile 77
#define Rxc_cores 78
#define Rxc_atolSens 79
#define Rxc_rtolSens 80
#define Rxc_ssAtolSens 81
#define Rxc_ssRtolSens 82
#define Rxc_simVariability 83
#define Rxc_nLlikAlloc 84
#define Rxc_useStdPow 85
#define Rxc_naTimeHandle 86
#define Rxc_addlKeepsCov 87
#define Rxc_addlDropSs 88
#define Rxc_ssAtDoseTime 89
#define Rxc_ss2cancelAllPending 90
#define Rxc_naInterpolation 91
#define Rxc_keepInterpolation 92
#define Rxc_safeLog 93
#define Rxc_safePow 94
#define Rxc_ssSolved 95
#define Rxc_linCmtSensType 96
#define Rxc_linCmtSensH 97
#define Rxc_linCmtGillFtol 98
#define Rxc_linCmtGillK 99
#define Rxc_linCmtGillStep 100
#define Rxc_linCmtGillRtol 101
#define Rxc_linCmtShiErr 102
#define Rxc_linCmtShiMax 103
#define Rxc_linCmtScale 104
#define Rxc_linCmtHcmt 105
#define Rxc_linCmtHmeanI 106
#define Rxc_linCmtHmeanO 107
#define Rxc_linCmtSuspect 108
#define Rxc_linCmtForwardMax 109
#define Rxc__zeros 110
#define RxMv_params 0
#define RxMv_lhs 1
#define RxMv_state 2
#define RxMv_trans 3
#define RxMv_model 4
#define RxMv_ini 5
#define RxMv_dfdy 6
#define RxMv_sens 7
#define RxMv_state_ignore 8
#define RxMv_version 9
#define RxMv_normal_state 10
#define RxMv_needSort 11
#define RxMv_nMtime 12
#define RxMv_extraCmt 13
#define RxMv_stateExtra 14
#define RxMv_dvid 15
#define RxMv_indLin 16
#define RxMv_flags 17
#define RxMv_slhs 18
#define RxMv_alag 19
#define RxMv_udf 20
#define RxMv_interp 21
#define RxMv_strAssign 22
#define RxMv_lhsStr 23
#define RxMv_stateProp 24
#define RxMv_sensProp 25
#define RxMv_normProp 26
#define RxMv_stateOrd 27
#define RxMv_lhsOrd 28
#define RxMv_timeId 29
#define RxMv_md5 30
#define RxMvFlag_ncmt 0
#define RxMvFlag_ka 1
#define RxMvFlag_linB 2
#define RxMvFlag_maxeta 3
#define RxMvFlag_maxtheta 4
#define RxMvFlag_hasCmt 5
#define RxMvFlag_linCmt 6
#define RxMvFlag_linCmtFlg 7
#define RxMvFlag_nIndSim 8
#define RxMvFlag_simflg 9
#define RxMvFlag_thread 10
#define RxMvFlag_nLlik 11
#define RxMvFlag_ndiff 12

#define RxMvTrans_lib_name 0
#define RxMvTrans_jac 1
#define RxMvTrans_prefix 2
#define RxMvTrans_dydt 3
#define RxMvTrans_calc_jac 4
#define RxMvTrans_calc_lhs 5
#define RxMvTrans_model_vars 6
#define RxMvTrans_theta 7
#define RxMvTrans_inis 8
#define RxMvTrans_dydt_lsoda 9
#define RxMvTrans_calc_jac_lsoda 10
#define RxMvTrans_ode_solver_solvedata 11
#define RxMvTrans_ode_solver_get_solvedata 12
#define RxMvTrans_dydt_liblsoda 13
#define RxMvTrans_F 14
#define RxMvTrans_Lag 15
#define RxMvTrans_Rate 16
#define RxMvTrans_Dur 17
#define RxMvTrans_mtime 18
#define RxMvTrans_assignFuns 19
#define RxMvTrans_ME 20
#define RxMvTrans_IndF 21
#define RxTrans_ndose 0
#define RxTrans_nobs 1
#define RxTrans_nid 2
#define RxTrans_cov1 3
#define RxTrans_covParPos 4
#define RxTrans_covParPosTV 5
#define RxTrans_sub0 6
#define RxTrans_baseSize 7
#define RxTrans_nTv 8
#define RxTrans_lst 9
#define RxTrans_nme 10
#define RxTrans_covParPos0 11
#define RxTrans_covUnits 12
#define RxTrans_pars 13
#define RxTrans_allBolus 14
#define RxTrans_allInf 15
#define RxTrans_mxCmt 16
#define RxTrans_lib_name 17
#define RxTrans_addCmt 18
#define RxTrans_cmtInfo 19
#define RxTrans_idLvl 20
#define RxTrans_allTimeVar 21
#define RxTrans_keepDosingOnly 22
#define RxTrans_censAdd 23
#define RxTrans_limitAdd 24
#define RxTrans_levelInfo 25
#define RxTrans_idInfo 26
#define RxTrans_maxShift 27
#define RxTrans_keepL 28
#define RxTrans_maxItemsPerId 29
#define RxTransNames CharacterVector _en(30);_en[0]="ndose";_en[1]="nobs";_en[2]="nid";_en[3]="cov1";_en[4]="covParPos";_en[5]="covParPosTV";_en[6]="sub0";_en[7]="baseSize";_en[8]="nTv";_en[9]="lst";_en[10]="nme";_en[11]="covParPos0";_en[12]="covUnits";_en[13]="pars";_en[14]="allBolus";_en[15]="allInf";_en[16]="mxCmt";_en[17]="lib_name";_en[18]="addCmt";_en[19]="cmtInfo";_en[20]="idLvl";_en[21]="allTimeVar";_en[22]="keepDosingOnly";_en[23]="censAdd";_en[24]="limitAdd";_en[25]="levelInfo";_en[26]="idInfo";_en[27]="maxShift";_en[28]="keepL";_en[29]="maxItemsPerId";e.names() = _en;

#endif // __rxode2parse_control_H__
